@@ -7,6 +7,7 @@ import json
 from Crypto.Cipher import AES, PKCS1_OAEP, PKCS1_v1_5
 from . import tp_link_cipher
 import ast
+import pkgutil
 
 #Old Functions to get device list from tplinkcloud
 def getToken(email, password):
@@ -31,6 +32,14 @@ def getDeviceList(email, password):
 
 	return requests.post(URL, json=Payload).json()
 
+ERROR_CODES = {
+	"0": "Success",
+	"-1010": "Invalid Public Key Length",
+	"-1501": "Invalid Request or Credentials",
+	"1002": "Incorrect Request",
+	"-1003": "JSON formatting error "
+}
+
 class P100():
 	def __init__ (self, ipAddress, email, password):
 		self.ipAddress = ipAddress
@@ -38,8 +47,7 @@ class P100():
 		self.email = email
 		self.password = password
 
-		with open("errorCodes.json") as f:
-			self.errorCodes = json.load(f)
+		self.errorCodes = ERROR_CODES
 
 		self.encryptCredentials(email, password)
 		self.createKeyPair()
